@@ -547,8 +547,9 @@ void create_file_dialog (      GtkWidget **dialog,
     g_autoptr(GFile) menu_folder = g_file_new_for_path (menu_folder_str);
     GtkFileFilter *file_filter;
 
-    // Translation note: the verb "Open".
-    *dialog = gtk_file_chooser_dialog_new ((open) ? _("Open Openbox Menu File") : 
+    *dialog = gtk_file_chooser_dialog_new ((open) ? // Translation note: Do not translate the word "Openbox". "Open" is a verb here.
+                                                    _("Open Openbox Menu File") : 
+                                                    // Translation note: Do not translate the word "Openbox".
 	                                                _("Save Openbox Menu File As…"), 
                                            GTK_WINDOW (ks.window),
                                            (open) ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE, 
@@ -563,6 +564,7 @@ void create_file_dialog (      GtkWidget **dialog,
     }
 
     file_filter = gtk_file_filter_new ();
+    // Translation note: Do not translate the word "Openbox".
     gtk_file_filter_set_name (file_filter, _("Openbox Menu Files"));
     gtk_file_filter_add_pattern (file_filter, "*.xml");
     gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (*dialog), file_filter);
