@@ -638,7 +638,7 @@ void row_selected (void)
         if (prompt_or_command_selected_and_action_is_Execute || startupnotify_or_option_of_it_selected) {
             // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, 
             // please use the indefinite form (“Option”), not the definite one (“The Option”).
-            gtk_label_set_text_with_mnemonic (GTK_LABEL (ks.bt_add_action_option_label), _("O_ption"));
+            gtk_label_set_text_with_mnemonic (GTK_LABEL (ks.bt_add_action_option_label), _("_Option"));
         }
 
         if (prompt_or_command_selected_and_action_is_Execute || 
@@ -652,7 +652,7 @@ void row_selected (void)
             else if (number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS - 1) {
                 gboolean execute_options_status[NUMBER_OF_EXECUTE_OPTS] = { 0 };
                 const gchar *execute_opts_with_mnemonic[] = { // Translation note: Do not translate this.
-				                                              N_("_Prompt"),
+				                                              N_("Pro_mpt"),
 															  // Translation note: Do not translate this.
 				                                              N_("_Command"), 
 															  // Translation note: Do not translate this.
